//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.3.0, Copyright (C) Russell Mok 1997
// 
// uIOEvent.h -- 
// 
// Author           : Russell Mok
// Created On       : Thu Dec 11 17:34:59 1997
// Last Modified By : Peter A. Buhr
// Last Modified On : Fri Jun 24 14:34:14 2005
// Update Count     : 106
//
// This  library is free  software; you  can redistribute  it and/or  modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
// option) any later version.
// 
// This library is distributed in the  hope that it will be useful, but WITHOUT
// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
// for more details.
// 
// You should  have received a  copy of the  GNU Lesser General  Public License
// along  with this library.
// 


#ifndef __U_IOEVENT_H__
#define __U_IOEVENT_H__


#pragma __U_NOT_USER_CODE__


_DualEvent uIOFailure {
    // general IO exception-type
    int uErrno;
  protected:
    uIOFailure( const char *const msg );
  public:
    virtual ~uIOFailure();
    int errNo() const;
}; // uIOFailure


#pragma __U_USER_CODE__

#endif // __U_IOEVENT_H__


// Local Variables: //
// compile-command: "gmake install" //
// End: //
